leaftools.iterate_leaf_pairs_forward_in_expr
============================================

.. autofunction:: abjad.tools.leaftools.iterate_leaf_pairs_forward_in_expr.iterate_leaf_pairs_forward_in_expr
